package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.remote.AuthRemote;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private AuthRemote remote;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private HttpServletRequest request;


    /**
     * 发送验证码
     *
     * @param phone
     */
    @Override
    public Result sendCode(String phone) {
        if(phone==null){
            return Result.error("该用户不存在,请先注册");
        }

        if(!phone.matches("^1[3-9]\\d{9}$")){
            return Result.error("手机号格式不正确");
        }

        //点击发送验证码、验证码随机生成
        Random random = new Random();
        int code = random.nextInt(1000 + 9000);
        System.out.println("发送的验证码是："+code);

        //验证码以手机号保存到redis当中，过期时间为5分钟
        redisTemplate.opsForValue().set(phone, String.valueOf(code),5, TimeUnit.MINUTES);
        return Result.success(code);
    }

    /**
     * 登录
     *
     * @param user
     */
    @Override
    public Result<JwtResponse> login(User user) {
        Result<User> userResult = remote.sendCode(user.getPhone());
        User data = userResult.getData();
        if(data==null){
            return Result.error("该用户不存在,请先注册");
        }

        if(!user.getPhone().matches("^1[3-9]\\d{9}$")){
            return Result.error("手机号格式不正确");
        }

        //获取验证码
        String code = redisTemplate.opsForValue().get("code");
        if(!code.equals(user.getCode())){
            return Result.error("验证码错误");
        }

        //获取token
        Map<String,Object> map=new HashMap<>();
        String userKey = UUID.randomUUID().toString().replace("-", "");
        map.put(JwtConstants.USER_KEY,userKey);
        String token = JwtUtils.createToken(map);

        //存到Redis
        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey,
                JSONObject.toJSONString(data),30,TimeUnit.MINUTES);
        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setExistTime("30MIN");

        return Result.success(jwtResponse);
    }

    /**
     * 获取用户信息
     */
    @Override
    public User info() {
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        String userJson = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        return JSONObject.parseObject(userJson,User.class);
    }

    /**
     * 退出
     */
    @Override
    public void logout() {
        String token = request.getHeader("token");
        String userKey = JwtUtils.getUserKey(token);
        redisTemplate.delete(userKey);
    }
}
