package com.bwie.common.domain;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Tag(name = "Orders",description = "订单信息表")
public class Orders {

    /**
     * 主键
     */
    @Schema(
            title = "主键",
            type = "Integer",
            description = "主键ID"
    )
    private Integer orderId;
    /**
     * 券码名称
     */
    @Schema(
            title = "券码名称",
            type = "String",
            description = "券码名称",
            defaultValue = "爱奇艺"
    )
    private String couponName;
    /**
     * 链接
     */
    @Schema(
            title = "链接",
            type = "String",
            description = "链接",
            defaultValue = "3fesfer231"
    )
    private String couponLink;
    /**
     * 有效期
     */
    @Schema(
            title = "有效期",
            type = "Date",
            description = "有效期",
            defaultValue = "2024-8-12 10:46:00"
    )
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date indate;
    /**
     * 购买的价格
     */
    @Schema(
            title = "购买的价格",
            type = "BigDecimal",
            description = "购买的价格",
            defaultValue = "50.44"
    )
    private BigDecimal price;
    /**
     * 状态
     */
    @Schema(
            title = "状态",
            type = "Integer",
            description = "买到券的状态",
            defaultValue = "0:寄售中 1:已销售 2:待使用 3:待打款 4:完成 5:关闭"
    )
    private Integer status;
    /**
     * 券码表主键
     */
    @Schema(
            title = "主键",
            type = "Integer",
            description = "券码主键id"
    )
    private Integer couponId;
    /**
     * 当前券码数量
     */
    @Schema(
            title = "当前券码数量",
            type = "Integer",
            description = "当前券码数量,增加一个订单数量加一",
            defaultValue = "12"
    )
    private Integer num;
    /**
     * 主键
     */
    @Schema(
            title = "主键",
            type = "Integer",
            description = "主键ID"
    )
    private Integer userId;
}
