package com.bwie.expressage.controller;

import com.alibaba.fastjson.JSONObject;
import com.bwie.common.domain.Orders;
import com.bwie.common.result.Result;
import com.bwie.expressage.service.OrderService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@RequestMapping("/orders")
@Log4j2
public class OrdersController {

    @Autowired
    private OrderService service;
    @Autowired
    private HttpServletRequest request;

    /**
     * 添加订单
     * @param orders
     * @return
     */
    @PostMapping("/add")
    public Result add(@RequestBody Orders orders){
        log.info("功能名称：添加订单，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orders));
        int add = service.add(orders);
        log.info("功能名称：添加订单，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orders));
        return Result.success(add);
    }

    /**
     * 查看订单列表
     * @return
     */
    @GetMapping("/showList")
    public Result showList(){
        log.info("功能名称：查看订单列表，请求URI:{}，请求方式：{}", request.getRequestURI(),
                request.getMethod());
        List<Orders> list = service.showList();
        log.info("功能名称：查看订单列表，请求URI:{}，请求方式：{}", request.getRequestURI(),
                request.getMethod());
        return Result.success(list);
    }

    /**
     * 点击确认收货，修改订单状态为完成
     * @param orderId
     * @return
     */
    @PostMapping("/ChangeStatus")
    public Result ChangeStatus(Integer orderId){
        log.info("功能名称：点击确认收货，修改订单状态为完成，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orderId));
        int i = service.changeStatus(orderId);
        log.info("功能名称：点击确认收货，修改订单状态为完成，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orderId));
        return Result.success(i);
    }

    //使用定时器进行若用户超过48小时未点击确认收货则自动确认收货
    @Scheduled(cron = "0 0 0 0/2 * *")
    public void test(){
        int i = service.checkStatus();
        System.out.println(i);
    }

    //减少
    @PostMapping("/less")
    public Result less(Integer orderId){
        log.info("功能名称：减少，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orderId));
        int less = service.less(orderId);
        log.info("功能名称：减少，请求URI:{}，请求方式：{}，请求参数：{}", request.getRequestURI(),
                request.getMethod(), JSONObject.toJSONString(orderId));
        return Result.success(less);
    }

}
