package com.bwie.expressage.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Orders;
import com.bwie.common.domain.User;
import com.bwie.common.utils.JwtUtils;
import com.bwie.expressage.mapper.CouponMapper;
import com.bwie.expressage.mapper.OrderMapper;
import com.bwie.expressage.service.OrderService;
import com.bwie.user.mapper.UserMapper;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.concurrent.TimeUnit;

@Service
public class OrderServiceImpl
        extends ServiceImpl<OrderMapper,Orders>
        implements OrderService {

    @Autowired
    private OrderMapper mapper;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Autowired
    private UserMapper userMapper;
    @Autowired
    private HttpServletRequest request;


    /**
     * 添加订单
     *
     * @param orders
     */
    @SneakyThrows
    @Override
    public int add(Orders orders) {
        int add = mapper.add(orders);
        if(0<add){
            //点击立刻寄售 - 数据落库，缓存到redis当中，当前券码数量+1
            mapper.update(orders.getCouponId());
            redisTemplate.opsForValue().set("orders:", String.valueOf(orders));
            return add;
        }
        throw new Exception("失败");
    }

    /**
     * 查看订单详情
     */
    @Override
    public List<Orders> showList() {
        List<Orders> list = mapper.showList();
        return list;
    }

    /**
     * 点击确认收货，修改订单状态为完成
     *
     * @param orderId
     */
    @SneakyThrows
    @Override
    public int changeStatus(Integer orderId) {
        int i = mapper.changeStatus(orderId);
        if(i>0){

            //获取用户信息
            String token = request.getHeader("token");
            String userKey = JwtUtils.getUserKey(token);
            String userJson = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
            User user = JSONObject.parseObject(userJson, User.class);

            Integer userId = user.getUserId();
            //确认收货加款
            userMapper.addMoney(userId);

            return i;
        }
        throw new Exception("未找到或已取完");
    }

    @Override
    public int checkStatus() {
        int i = mapper.checkStatus();
        return i;
    }

    @SneakyThrows
    @Override
    public int less(Integer orderId) {
        int less = mapper.less(orderId);
        if(less>0){
            mapper.updateStatus(orderId);
            return less;
        }
        throw new Exception("操作失败");
    }

}
